@@ -108,7 +108,7 @@ use Scalar::Util 'blessed';
 use Business::cXML::Transmission;
 
 BEGIN {
-	our $VERSION = 'v0.6.3';
+	our $VERSION = 'v0.6.4';
 	our $CXML_VERSION = '1.2.036';
 	our $USERAGENT = "Business::cXML.pm $VERSION";
 }
@@ -536,6 +536,10 @@ sub stringify {
 
 =back
 
+=head1 VERSION
+
+0.6.4 based on cXML DTD 1.2.036
+
 =head1 AUTHOR
 
 Stéphane Lavergne L<https://github.com/vphantom>
