@@ -166,7 +166,7 @@ sub _new_payload {
 	my ($self, $msg) = @_;
 	my $status;
 
-	$self->is_test(1) if ($msg->{deploymentMode} eq 'test');
+	$self->is_test(1) if (exists $msg->{deploymentMode} && $msg->{deploymentMode} eq 'test');
 	$self->{inreplyto} = $msg->{inReplyTo} if exists $msg->{inReplyTo};
 	# UNIMPLEMENTED Message/Request/Response: Id?
 
@@ -243,7 +243,7 @@ Optional, override submit button HTML with your own
 
 sub toForm {
 	my ($self, %args) = @_;
-	my $url = encode_entities($args{url});
+	my $url = encode_entities($args{url} || '');
 	my $submit = '<input type="submit">';
 	$submit = $args{submit_button} if exists $args{submit_button};
 	my $target = '';
@@ -378,6 +378,7 @@ sub reply_to {
 	$self->{type} = $req->{type};
 
 	$self->inreplyto($req->{id});
+	$self->is_test($req->is_test);
 
 	$self->sender->copy($req->to);
 	$self->sender->contact(undef);
